define([
	"dojo/_base/declare",
	"dojo/_base/lang",
	"dojo/_base/array",
	"thornberry/app/Component/_Component",
    "thornberry/app/Component/_ViewMixin",
    "thornberry/app/Component/_DataFormMixin",
    "dijit/_TemplatedMixin",
    "thornberry/app/utils",
    "thornberry/app/Service/BillingManagement",
    "dojo/dom-construct",
    "dojo/dom-style",
    "dojo/text!./Templates/ClaimResponseFileDetailsView.html",
    "./ClaimResponseItem"
],function(
	declare,
	lang,
	arrayUtils,
    _Component,
    _ViewMixin,
    _DataFormMixin,
    _TemplatedMixin,
    utils,
    service,
    domConstruct,
    domStyle,
    template,
    ClaimResponseItem
) {
	var canPostToAR = false;
	utils.checkPermission("BillingPostClaimsToAR",false).then(function(allowed){canPostToAR=!!allowed});
	
	return declare([_Component,_ViewMixin,_DataFormMixin,_TemplatedMixin], {
        title: "Details",
        
        templateString: template,

        objectId: null,
        object: null,

        claimResponseItems: null,

        constructor: function() {
            var t = this;
            t.claimResponseItems = [];
        }, 

        getTitle: function() {
            var t = this;
            var title = "Details";
            if (t.object) {
                title = "Details - " + (t.object.receiveMethod == "Interface" ? t.object.icn : t.object.fileName) + " - " + t.object.responseType;
            }
            return title;
        },

		getInitialProps: function() {
            var t = this;
			return lang.mixin(this.inherited(arguments), {
                objectId: "",
                onComplete: null
			});
		},

		getPageProps: function() {
            var t = this;
            var canEdit = (t.object && t.object.isDeleted != 1 && t.object.isProcessed != 1);

			var itemActions = [];
			if (canPostToAR) {
				itemActions.push({ label: "Process", onClick: function() {t.save().then(t.props.onCloseView)}, hidden: !canEdit });
			}
			itemActions.push({ label: "Delete", onClick: lang.hitch(t,"deleteItem"), hidden: !canEdit });

			return lang.mixin(t.inherited(arguments), {
                content: t.domNode,
                actions: [
                    { label: "Back", onClick: t.props.onCloseView },
                    itemActions
                ],
				accountSummaryShown: false
			});
        },
        
        refreshRendering: function() {
            var t = this;
            t.set("objectId",t.props.objectId);
            t.inherited(arguments);
        },

		_setObjectIdAttr: function(value) {
			var t = this;
			if (value && t.objectId !== value) {
				t.addReadyPromise(service.getClaimResponseFile(value).then(function(object) {
					if (t.objectId === value) {
                        t.set("object",object);
                        t.set("value",object);

                        
					}
				}));
			} else if (!value) {
				t.set("object", null);
			}
			t.objectId = value;
        },
        
        _setObjectAttr: function(value) {
            var t = this;
            t.object = value;

            var claims = t.object.claims;
            var errors = claims[""] ? claims[""].errors : [];
            domStyle.set(t.errorContainer,"display",errors.length ? "" : "none");
            domConstruct.empty(t.errorItemContainer);
            arrayUtils.forEach(errors,function(error) {
                var node = domConstruct.toDom("<div></div>");
                t.errorItemContainer.appendChild(node);
                node.innerHTML = error;
            });

            arrayUtils.forEach(t.claimResponseItems,function(item) { item.destroy(); });
            var count = 0;
            for (claimId in claims) {
                if (claimId != "") {
                    count++;
                    var claimResponseItem = new ClaimResponseItem({
                        props: {
                            value: claims[claimId]
                        }
                    });
                    t.claimItemContainer.appendChild(claimResponseItem.domNode);
                    t.claimResponseItems.push(claimResponseItem);
                }
            }
            domStyle.set(t.claimContainer,"display",count ? "" : "none");

            t.setPageProps();
        },

        _setValueAttr: function(value) {
            var t = this;
            t.inherited(arguments);

            t.value = value;
            if (value) {
                domStyle.set(t.fileNameContainer,"display",value.receiveMethod === "Interface" ? "none" : "");
                domStyle.set(t.icnContainer,"display",value.receiveMethod === "Upload" ? "none" : "");
                domStyle.set(t.response999Container,"display",t.object.responseType == "999" ? "" : "none");
                domStyle.set(t.response277CAContainer,"display",t.object.responseType == "277CA" ? "" : "none");
				domStyle.set(t.response277CAContainerStatus,"display",t.object.responseType == "277CA" ? "none" : "");
            }
        }, 

        save: function() {
            var t = this;
            return service.processClaimResponseFile(t.objectId).then(function() {
                t.objectId = null;
                if (t.props.onComplete) {
                    t.props.onComplete();
                }
            },utils.showMessage);
        },

        deleteItem: function() {
            var t = this;
            utils.showMessage("Are you sure you want to delete this claim response file?",[
                { label: "Yes", callback: function() {
                    service.deleteClaimResponseFile(t.objectId).then(function() {
                        t.props.onCloseView();
                        t.objectId = null;
                        if (t.props.onComplete) {
                            t.props.onComplete();
                        }
                    },utils.showMessage);
                } },{
                    label: "No"
                }
            ]);
        },

        onShow: function() {
            var t = this;
            t.inherited(arguments);
            if (t.firstShow) {
				t.addSubView("claimFileDetails","thornberry/app/Component/BillingManagement/ClaimFileDetailsView",function() {
                    return {
                        viewOnly: true
                    };
                });
            }
        },

        _viewClaimFile: function() {
            var t = this;
            var promise = service.getClaimFileDetails(t.object.responseTo.id).then(function(result) {
                t.loadSubView("claimFileDetails",{
                    value: result
                });
            },utils.showMessage);
            t.props.onSetLoadingPromise(promise);
        }
	});
});